<?php
 namespace App\Controller\Frontend; use Symfony\Component\HttpFoundation\Request; use Symfony\Component\HttpFoundation\Response; use Symfony\Component\Form\Form; use Symfony\Component\Form\Extension\Core\Type\SubmitType; use Symfony\Contracts\Translation\TranslatorInterface; use Symfony\Component\Validator\Validator\ValidatorInterface; use Symfony\Component\Validator\ConstraintViolationList; use App\Controller\Controller; use App\Event\EventQueue; use App\Service\Logger; use App\Entity\Site as SiteEntity; use App\Entity\Certificate as CertificateEntity; use App\Entity\NodejsSettings as NodejsSettingsEntity; use App\Entity\PhpSettings as PhpSettingsEntity; use App\Entity\PythonSettings as PythonSettingsEntity; use App\Entity\Database as DatabaseEntity; use App\Entity\DatabaseUser as DatabaseUserEntity; use App\Entity\DatabaseServer as DatabaseServerEntity; use App\Entity\User as UserEntity; use App\Entity\Manager\ConfigManager; use App\Entity\Manager\SiteManager as SiteEntityManager; use App\Entity\Manager\CertificateManager as CertificateEntityManager; use App\Entity\Manager\DatabaseManager as DatabaseEntityManager; use App\Entity\Manager\DatabaseUserManager as DatabaseUserEntityManager; use App\Entity\Manager\DatabaseServerManager as DatabaseServerEntityManager; use App\Entity\Manager\VhostTemplateManager as VhostTemplateEntityManager; use App\Database\Connection as DatabaseConnection; use App\Database\Manager as DatabaseManager; use App\Site\Nginx\Vhost\StaticTemplate as StaticVhostTemplate; use App\Site\Nginx\Vhost\PhpTemplate as PhpVhostTemplate; use App\Site\Nginx\Vhost\PythonTemplate as PythonVhostTemplate; use App\Site\Nginx\Vhost\ReverseProxyTemplate as ReverseProxyVhostTemplate; use App\Site\Nginx\Vhost\Processor\RedirectDomain as RedirectDomainProcessor; use App\Site\Nginx\Vhost\Processor\RedirectServerName as RedirectServerNameProcessor; use App\Site\Nginx\Vhost\Processor\ServerName as ServerNameProcessor; use App\Site\Parser\DomainName as DomainNameParser; use App\Site\Ssl\Generator\RsaKeyGenerator; use App\Site\Creator\NodejsSite as NodejsSiteCreator; use App\Site\Creator\StaticSite as StaticSiteCreator; use App\Site\Creator\PhpSite as PhpSiteCreator; use App\Site\Creator\PythonSite as PythonSiteCreator; use App\Site\Creator\ReverseProxySite as ReverseProxySiteCreator; use App\Site\Ssl\DistinguishedName; use App\Site\Ssl\Generator\CsrGenerator; use App\Site\Ssl\Util\Openssl; use App\Site\NodejsSite; use App\Site\StaticSite; use App\Site\PhpSite; use App\Site\PythonSite; use App\Site\ReverseProxySite; use App\Util\PasswordGenerator; use App\Site\Application\WordPressInstaller; use App\Service\Crypto; class NewSiteController extends Controller { private const WORDPRESS_VHOST_TEMPLATE_NAME = "\x57\157\x72\x64\x50\162\x65\163\x73"; private const NODEJS_VHOST_TEMPLATE_NAME = "\116\157\144\x65\x6a\x73"; private const STATIC_SITE_VHOST_TEMPLATE_NAME = "\123\x74\141\x74\x69\143"; private const PYTHON_VHOST_TEMPLATE_NAME = "\120\x79\164\x68\x6f\156"; private const REVERSE_PROXY_VHOST_TEMPLATE_NAME = "\x52\145\x76\145\162\163\145\120\162\x6f\170\x79"; private const VARNISH_CACHE_SERVER = "\61\62\67\x2e\x30\x2e\x30\x2e\61\72\x36\60\70\61"; private const PASSWORD_LENGTH = 20; private ConfigManager $configManager; private SiteEntityManager $siteEntityManager; private CertificateEntityManager $certificateEntityManager; private DatabaseEntityManager $databaseEntityManager; private DatabaseUserEntityManager $databaseUserEntityManager; private DatabaseServerEntityManager $databaseServerEntityManager; private DomainNameParser $domainNameParser; private VhostTemplateEntityManager $vhostTemplateEntityManager; private ValidatorInterface $validator; private array $wordPressDefaultConfigValues = ["\106\123\x5f\x4d\x45\x54\110\x4f\x44" => ["\166\x61\154\x75\x65" => "\x64\151\162\145\x63\x74", "\162\x61\167" => false], "\x57\x50\x5f\104\x45\x42\x55\107\137\104\111\123\120\x4c\x41\131" => ["\166\x61\154\x75\x65" => "\146\x61\154\163\145", "\162\x61\167" => true], "\x57\120\137\x44\105\x42\x55\x47\137\x4c\x4f\107" => ["\x76\x61\x6c\165\145" => "\x74\x72\165\x65", "\162\x61\x77" => true], "\x43\117\x4e\103\101\x54\x45\x4e\x41\124\105\137\x53\103\x52\x49\120\124\123" => ["\166\141\154\165\145" => "\x66\141\154\163\145", "\162\x61\x77" => true], "\x41\125\x54\117\x53\101\126\105\137\x49\x4e\124\x45\122\x56\101\x4c" => ["\x76\141\x6c\165\x65" => 600, "\x72\141\167" => true], "\x57\120\x5f\120\x4f\x53\x54\137\x52\105\x56\111\x53\x49\117\116\x53" => ["\x76\141\154\165\x65" => 5, "\x72\141\x77" => true], "\x45\115\120\x54\131\x5f\124\x52\101\x53\110\137\x44\101\x59\x53" => ["\x76\141\x6c\165\145" => 21, "\162\x61\x77" => true]]; private array $wordPressMultiSiteConfigValues = ["\127\x50\137\x41\114\114\117\127\x5f\115\x55\114\124\111\123\x49\124\x45" => ["\166\x61\154\165\x65" => "\164\x72\x75\145", "\x72\141\167" => true], "\x4d\x55\114\124\x49\123\111\x54\x45" => ["\x76\x61\154\165\145" => "\x74\x72\165\145", "\x72\x61\167" => true], "\123\x55\x42\104\117\x4d\101\x49\116\x5f\x49\116\123\x54\101\x4c\114" => ["\166\141\x6c\165\145" => "\146\x61\154\x73\x65", "\162\x61\167" => true], "\x44\117\x4d\x41\x49\x4e\137\103\125\x52\x52\105\x4e\x54\x5f\x53\x49\x54\x45" => ["\166\x61\x6c\x75\x65" => '', "\x72\x61\x77" => false], "\x50\x41\x54\110\137\x43\x55\122\122\x45\116\124\x5f\x53\x49\124\105" => ["\x76\141\x6c\x75\x65" => "\x2f", "\x72\141\x77" => false], "\x53\x49\124\x45\x5f\111\104\137\x43\x55\x52\122\105\x4e\124\x5f\123\111\x54\105" => ["\x76\x61\154\x75\145" => 1, "\x72\141\167" => true], "\x42\x4c\x4f\107\137\x49\104\137\103\125\122\122\105\x4e\x54\x5f\123\x49\x54\x45" => ["\x76\x61\154\x75\x65" => 1, "\162\x61\x77" => true]]; public function __construct(ConfigManager $configManager, SiteEntityManager $siteEntityManager, CertificateEntityManager $certificateEntityManager, DatabaseEntityManager $databaseEntityManager, DatabaseUserEntityManager $databaseUserEntityManager, DatabaseServerEntityManager $databaseServerEntityManager, VhostTemplateEntityManager $vhostTemplateEntityManager, DomainNameParser $domainNameParser, ValidatorInterface $validator, TranslatorInterface $translator, Logger $logger) { goto f27ee; Aad38: $this->siteEntityManager = $siteEntityManager; goto Ac0d9; b6c78: $this->validator = $validator; goto B3660; Bf31b: $this->databaseServerEntityManager = $databaseServerEntityManager; goto d9b26; d9b26: $this->vhostTemplateEntityManager = $vhostTemplateEntityManager; goto fb7a0; Ac0d9: $this->certificateEntityManager = $certificateEntityManager; goto c1b1c; fb7a0: $this->domainNameParser = $domainNameParser; goto b6c78; c1b1c: $this->databaseEntityManager = $databaseEntityManager; goto b6ae3; b6ae3: $this->databaseUserEntityManager = $databaseUserEntityManager; goto Bf31b; B3660: parent::__construct($translator, $logger); goto C556e; f27ee: $this->configManager = $configManager; goto Aad38; C556e: } public function index(Request $request) : Response { goto B967d; E4757: $user = $this->getUser(); goto be8b8; F1c07: $response = $this->redirect($this->generateUrl("\143\x6c\160\x5f\x73\151\x74\x65\x73")); goto d78ec; d1331: return $response; goto e9fc1; B967d: $hasPermissions = $this->hasPermissions(); goto C1380; be8b8: $response = $this->render("\x46\x72\x6f\x6e\164\145\x6e\x64\57\123\151\164\x65\x2f\x4e\145\167\x2f\151\156\x64\145\x78\x2e\x68\x74\155\154\x2e\164\x77\151\x67", ["\x75\163\x65\x72" => $user]); goto da671; C1380: if (true === $hasPermissions) { goto dd19e; } goto F1c07; da671: Ae8b4: goto d1331; Ac649: dd19e: goto E4757; d78ec: goto Ae8b4; goto Ac649; e9fc1: } public function newPythonSite(Request $request) : Response { goto beb66; beb66: $hasPermissions = $this->hasPermissions(); goto A9bf5; C97b4: $form->handleRequest($request); goto A3728; A9bf5: if (true === $hasPermissions) { goto aa7b2; } goto Bcec6; Ede06: b9b9c: goto a79a5; Df8b4: if (!(true === $request->isMethod("\x50\x4f\123\x54"))) { goto Efd11; } goto C97b4; A3728: if (!(true === $form->isSubmitted())) { goto ec100; } goto B73f9; ee56a: if (!(false === is_null($response))) { goto b9b9c; } goto c62c9; B1d9c: goto Dc213; goto Fc3de; B73f9: $response = $this->handleCreatePythonSiteForm($request, $form); goto ee56a; Bcec6: $response = $this->redirect($this->generateUrl("\x63\154\x70\x5f\x73\x69\x74\145\163")); goto B1d9c; Fc3de: aa7b2: goto fa1b7; A8aca: $form = $this->createPythonSiteForm($pythonSettings); goto Df8b4; D41d2: Efd11: goto c1da6; c62c9: return $response; goto Ede06; c1da6: $response = $this->render("\x46\162\157\x6e\164\145\156\144\x2f\123\x69\164\145\57\x4e\145\167\57\160\x79\x74\x68\x6f\156\x2e\x68\164\155\x6c\56\x74\167\x69\x67", ["\165\x73\x65\162" => $user, "\x66\157\162\x6d" => $form->createView(), "\146\x6f\x72\x6d\x45\162\x72\157\162\163" => $this->formErrors]); goto B0c2a; B0c2a: Dc213: goto a5b36; fdac1: $pythonSettings = new PythonSettingsEntity(); goto A8aca; a79a5: ec100: goto D41d2; a5b36: return $response; goto D3d1b; fa1b7: $user = $this->getUser(); goto fdac1; D3d1b: } private function createPythonSiteForm(PythonSettingsEntity $pythonSettings) : Form { goto e5ed7; d0c13: return $form; goto C682c; d6fea: $form->add("\163\165\x62\155\x69\164", SubmitType::class, ["\x61\164\x74\162" => ["\143\154\x61\163\163" => "\x62\x74\x6e\x20\142\164\x6e\x2d\x6c\147\x20\x62\164\156\x2d\142\x6c\165\145"], "\x6c\x61\142\145\x6c" => "\x43\162\x65\x61\x74\145"]); goto d0c13; e5ed7: $form = $this->createForm("\x41\x70\160\134\106\x6f\x72\x6d\x5c\123\151\x74\x65\116\x65\167\120\x79\x74\150\157\x6e\x54\171\x70\145", $pythonSettings, ["\141\143\164\151\157\x6e" => $this->generateUrl("\143\x6c\160\137\163\151\x74\145\x5f\160\171\x74\x68\157\x6e\137\156\x65\167"), "\x6d\145\164\x68\x6f\x64" => "\x50\x4f\123\124", "\x61\164\164\x72" => ["\x69\144" => "\156\145\167\x2d\160\171\x74\x68\157\x6e\x2d\163\x69\x74\x65\x2d\146\x6f\162\x6d"]]); goto d6fea; C682c: } private function handleCreatePythonSiteForm(Request $request, Form $form) { goto e3a8a; A923f: goto afae0; goto Eac3a; db82e: $this->formErrors = $this->getErrorMessages($form); goto A923f; Df33e: afae0: goto e1988; Af6f9: try { goto f14cf; C80f2: $user = $this->getUser(); goto B8e1d; cd739: $domainName = $form->get("\x64\x6f\x6d\141\x69\156\x4e\x61\155\x65")->getData(); goto Ef5bf; B9e25: if (false === is_null($vhostTemplateEntity)) { goto d2461; } goto A8c5d; Ef5bf: $pythonVersion = $form->get("\160\171\164\150\157\156\x56\x65\x72\x73\151\157\x6e")->getData(); goto a9e59; bedba: $response = $this->redirect($this->generateUrl("\143\x6c\160\x5f\x73\151\164\145\x73")); goto a355c; a9e59: $port = $form->get("\160\x6f\162\x74")->getData(); goto F91cf; B8e1d: $this->createPythonSite($domainName, $pythonVersion, $port, $siteUser, $siteUserPassword); goto B9119; Cca99: $session->getFlashBag()->set("\x73\165\143\x63\145\x73\x73", $this->translator->trans("\x53\x69\164\x65\40\x68\x61\x73\40\142\145\145\156\40\143\162\x65\141\x74\145\x64\56")); goto bedba; Aff00: $siteUserPassword = $form->get("\x73\x69\164\145\x55\163\x65\162\120\141\163\x73\167\157\162\x64")->getData(); goto d1116; a355c: return $response; goto F6c48; eee5d: goto C6492; goto d7361; d7361: d2461: goto C80f2; d1116: $vhostTemplateName = self::PYTHON_VHOST_TEMPLATE_NAME; goto Ecebf; F6c48: C6492: goto C1719; a33f5: EventQueue::addEvent(EventQueue::EVENT_SITE_PYTHON_CREATE, $user, $eventData, $request); goto Cca99; F91cf: $siteUser = $form->get("\x73\x69\164\x65\125\163\145\162")->getData(); goto Aff00; Ecebf: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto B9e25; B9119: $eventData = ["\163\151\164\145" => $domainName, "\163\151\164\x65\125\x73\x65\162" => $siteUser, "\160\x79\164\x68\157\x6e\126\145\x72\163\151\x6f\x6e" => $pythonVersion, "\x70\x6f\162\164" => $port]; goto a33f5; A8c5d: throw new \Exception(sprintf("\126\x68\157\163\x74\40\164\x65\x6d\x70\154\141\164\x65\x20\42\45\x73\42\40\156\157\164\40\x66\x6f\x75\156\x64\56", $vhostTemplateName)); goto eee5d; f14cf: $session = $request->getSession(); goto cd739; C1719: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\x61\156\147\x65\x72", $this->translator->trans("\x41\x6e\40\145\x72\x72\157\162\x20\150\x61\x73\x20\157\x63\x63\165\x72\x72\x65\x64\x2c\40\x65\x72\162\157\x72\40\155\145\163\163\x61\147\x65\x3a\x20\x25\145\x72\162\x6f\162\115\145\163\x73\141\x67\145\x25", ["\45\145\162\x72\157\x72\x4d\145\163\163\141\x67\x65\45" => $e->getMessage()])); } goto Df33e; Eac3a: D1450: goto Af6f9; e3a8a: if (true === $form->isValid()) { goto D1450; } goto db82e; e1988: } public function newReverseProxy(Request $request) : Response { goto e14b3; B6cf9: if (!(false === is_null($response))) { goto dfcdf; } goto Db78a; Cb7bb: bb3bf: goto f7a76; Db78a: return $response; goto Dbe67; a594b: if (true === $hasPermissions) { goto b2ca8; } goto ae447; cd499: b2ca8: goto a8504; e14b3: $hasPermissions = $this->hasPermissions(); goto a594b; E495a: $response = $this->handleReverseProxyForm($request, $form); goto B6cf9; ae447: $response = $this->redirect($this->generateUrl("\143\154\x70\x5f\163\x69\x74\145\x73")); goto dd51d; Dbe67: dfcdf: goto c76cc; Fdc50: c4baf: goto e6a13; A0012: if (!(true === $form->isSubmitted())) { goto f09aa; } goto E495a; c76cc: f09aa: goto Cb7bb; dd51d: goto c4baf; goto cd499; e6a13: return $response; goto a161b; f7a76: $response = $this->render("\x46\x72\x6f\156\164\x65\x6e\144\x2f\x53\151\164\x65\57\x4e\145\167\57\x72\145\166\145\162\163\x65\x2d\160\162\157\170\171\x2e\150\164\x6d\154\56\x74\167\151\147", ["\165\163\145\x72" => $user, "\x66\157\x72\x6d" => $form->createView(), "\x66\157\162\x6d\x45\162\x72\x6f\162\163" => $this->formErrors]); goto Fdc50; D4de6: $form = $this->createReverseProxyForm(); goto Cf8a1; Cf8a1: if (!(true === $request->isMethod("\120\117\123\x54"))) { goto bb3bf; } goto Be2c7; a8504: $user = $this->getUser(); goto D4de6; Be2c7: $form->handleRequest($request); goto A0012; a161b: } private function createReverseProxyForm() : Form { goto e5854; e5854: $form = $this->createForm("\x41\160\160\134\106\x6f\x72\x6d\134\x53\151\x74\145\x4e\x65\167\x52\x65\166\145\x72\163\145\x50\x72\157\x78\x79\x54\171\160\x65", [], ["\x61\x63\x74\x69\157\x6e" => $this->generateUrl("\x63\x6c\x70\137\x73\151\164\145\x5f\x72\x65\x76\145\162\163\145\x5f\160\162\157\x78\x79\x5f\156\x65\x77"), "\x6d\145\164\x68\x6f\x64" => "\120\x4f\123\124", "\141\x74\x74\162" => ["\x69\x64" => "\156\145\167\x2d\162\x65\166\145\x72\x73\x65\x2d\160\x72\157\x78\x79\55\x66\157\x72\x6d"]]); goto Cc74a; d4354: return $form; goto F8b16; Cc74a: $form->add("\x73\165\142\x6d\151\x74", SubmitType::class, ["\x61\x74\x74\162" => ["\x63\154\141\x73\163" => "\x62\164\156\40\x62\164\x6e\x2d\154\147\x20\142\164\156\x2d\142\x6c\x75\x65"], "\x6c\141\142\145\154" => "\x43\162\x65\x61\164\x65"]); goto d4354; F8b16: } private function handleReverseProxyForm(Request $request, Form $form) { goto e65d9; eac10: try { goto F4e5a; efb1c: $domainName = $form->get("\x64\157\x6d\x61\151\156\x4e\141\155\x65")->getData(); goto Da40c; b4dc6: $session->getFlashBag()->set("\x73\x75\x63\143\x65\x73\163", $this->translator->trans("\x52\145\x76\145\x72\163\x65\x20\x50\162\157\170\171\40\x68\141\163\40\x62\145\145\x6e\40\x63\x72\145\x61\164\x65\144\56")); goto cc891; cc891: $response = $this->redirect($this->generateUrl("\143\x6c\x70\x5f\x73\151\x74\145\x73")); goto bf9c0; aba86: $eventData = ["\163\x69\164\x65" => $domainName, "\x73\151\x74\x65\125\163\x65\x72" => $siteUser, "\x72\145\x76\x65\162\163\x65\120\162\x6f\x78\171\125\x72\154" => $reverseProxyUrl]; goto Beae2; e9df6: $vhostTemplateName = self::REVERSE_PROXY_VHOST_TEMPLATE_NAME; goto D915e; a791f: if (false === is_null($vhostTemplateEntity)) { goto F0d6a; } goto F9f93; db1c5: $reverseProxyUrl = $form->get("\162\145\166\145\162\163\x65\120\162\157\x78\x79\x55\162\154")->getData(); goto e9df6; Beae2: EventQueue::addEvent(EventQueue::EVENT_SITE_REVERSE_PROXY_CREATE, $user, $eventData, $request); goto b4dc6; Da40c: $siteUser = $form->get("\x73\x69\164\145\x55\x73\x65\x72")->getData(); goto F79b2; F4e5a: $session = $request->getSession(); goto efb1c; fe65c: Cde8f: goto Bcacd; fdd62: F0d6a: goto b7b0d; D915e: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto a791f; D13fe: $this->createReverseProxySite($domainName, $reverseProxyUrl, $siteUser, $siteUserPassword); goto aba86; F9f93: throw new \Exception(sprintf("\126\x68\157\163\x74\40\x74\145\x6d\160\x6c\141\x74\x65\x20\42\45\163\x22\40\x6e\x6f\164\x20\x66\157\x75\x6e\x64\x2e", $vhostTemplateName)); goto e33b3; F79b2: $siteUserPassword = $form->get("\x73\151\x74\x65\x55\163\x65\162\x50\x61\163\x73\x77\x6f\162\x64")->getData(); goto db1c5; e33b3: goto Cde8f; goto fdd62; b7b0d: $user = $this->getUser(); goto D13fe; bf9c0: return $response; goto fe65c; Bcacd: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\x61\156\147\x65\x72", $this->translator->trans("\101\156\40\145\x72\162\157\x72\x20\150\x61\163\x20\x6f\x63\x63\165\x72\x72\x65\x64\x2c\x20\x65\162\162\157\162\40\155\x65\x73\163\x61\x67\x65\72\40\45\x65\x72\162\x6f\x72\115\145\x73\x73\141\147\145\45", ["\x25\145\162\x72\x6f\x72\115\x65\163\163\141\x67\x65\x25" => $e->getMessage()])); } goto Fe548; Fe548: B34ba: goto c05f1; Cec1c: e0aa3: goto eac10; e65d9: if (true === $form->isValid()) { goto e0aa3; } goto d38e4; d38e4: $this->formErrors = $this->getErrorMessages($form); goto e9877; e9877: goto B34ba; goto Cec1c; c05f1: } public function newNodejsSite(Request $request) : Response { goto e1bd7; Ffc4d: if (true === $hasPermissions) { goto F7200; } goto c1486; e229e: D1a04: goto bb94e; E7a58: goto B541f; goto C18c1; Dd90e: return $response; goto e229e; Add62: $form->handleRequest($request); goto fb870; c28e2: $response = $this->render("\106\162\x6f\156\164\145\156\144\57\x53\x69\164\145\x2f\x4e\x65\167\57\x6e\x6f\x64\145\x6a\163\56\x68\164\x6d\x6c\x2e\164\167\151\147", ["\x75\163\145\x72" => $user, "\x66\x6f\162\155" => $form->createView(), "\146\x6f\162\155\x45\162\162\157\162\x73" => $this->formErrors]); goto D7f51; e1bd7: $hasPermissions = $this->hasPermissions(); goto Ffc4d; Bf6d9: $form = $this->createNodejsSiteForm($nodejsSettings); goto eddb2; C68c5: return $response; goto A2fe0; Bca77: $response = $this->handleCreateNodejsSiteForm($request, $form); goto E361a; fc707: $user = $this->getUser(); goto Dc5dd; Dc5dd: $nodejsSettings = new NodejsSettingsEntity(); goto Bf6d9; D7f51: B541f: goto C68c5; C18c1: F7200: goto fc707; fb870: if (!(true === $form->isSubmitted())) { goto D88c3; } goto Bca77; c1486: $response = $this->redirect($this->generateUrl("\143\154\160\x5f\163\x69\164\x65\x73")); goto E7a58; eddb2: if (!(true === $request->isMethod("\120\117\123\124"))) { goto B5cca; } goto Add62; cb80d: B5cca: goto c28e2; E361a: if (!(false === is_null($response))) { goto D1a04; } goto Dd90e; bb94e: D88c3: goto cb80d; A2fe0: } private function createNodejsSiteForm(NodejsSettingsEntity $nodejsSettings) : Form { goto Dacb9; e5271: return $form; goto A5b29; Dacb9: $form = $this->createForm("\x41\x70\x70\x5c\106\157\x72\x6d\134\x53\151\x74\x65\116\x65\167\116\x6f\x64\145\x6a\x73\x54\x79\x70\145", $nodejsSettings, ["\141\x63\x74\x69\x6f\156" => $this->generateUrl("\143\154\x70\137\163\151\164\145\137\x6e\157\144\x65\x6a\x73\137\156\145\x77"), "\x6d\x65\x74\x68\x6f\x64" => "\120\117\123\x54", "\141\164\164\162" => ["\151\x64" => "\156\x65\x77\55\x6e\x6f\x64\x65\x6a\x73\55\163\151\164\x65\55\146\x6f\162\x6d"]]); goto d9940; d9940: $form->add("\163\165\x62\x6d\x69\164", SubmitType::class, ["\141\164\164\162" => ["\143\x6c\x61\x73\163" => "\142\164\156\40\x62\x74\x6e\x2d\x6c\147\x20\x62\164\x6e\55\x62\154\x75\145"], "\x6c\141\142\145\x6c" => "\x43\162\145\x61\x74\145"]); goto e5271; A5b29: } private function handleCreateNodejsSiteForm(Request $request, Form $form) { goto e1e0d; e4e03: a0a64: goto B9375; e1e0d: if (true === $form->isValid()) { goto a0a64; } goto C603f; B9375: try { goto B7375; Efa3f: if (false === is_null($vhostTemplateEntity)) { goto E7782; } goto aa992; c2d61: $response = $this->redirect($this->generateUrl("\143\x6c\160\x5f\x73\x69\164\145\x73")); goto dc544; Eb761: goto cf22f; goto D9cb0; C7ba5: $siteUser = $form->get("\163\151\164\145\x55\163\x65\162")->getData(); goto fec7f; f12b2: $port = $form->get("\x70\x6f\x72\164")->getData(); goto C7ba5; eb5b7: $user = $this->getUser(); goto e314e; B7375: $session = $request->getSession(); goto D45a9; D9cb0: E7782: goto eb5b7; bf997: cf22f: goto F6ad3; daced: $session->getFlashBag()->set("\x73\x75\x63\143\145\x73\163", $this->translator->trans("\x53\151\x74\145\40\x68\x61\163\x20\142\x65\x65\156\x20\x63\162\x65\x61\164\x65\x64\56")); goto c2d61; D45a9: $domainName = $form->get("\144\157\155\141\x69\x6e\116\x61\x6d\145")->getData(); goto f6dd1; e623e: $vhostTemplateName = self::NODEJS_VHOST_TEMPLATE_NAME; goto Defb0; Defb0: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto Efa3f; fec7f: $siteUserPassword = $form->get("\163\x69\164\x65\125\163\145\x72\x50\x61\163\163\167\157\162\144")->getData(); goto e623e; c3549: EventQueue::addEvent(EventQueue::EVENT_SITE_NODEJS_CREATE, $user, $eventData, $request); goto daced; aa992: throw new \Exception(sprintf("\126\150\157\x73\x74\x20\164\x65\155\x70\x6c\x61\164\x65\40\42\45\163\x22\40\x6e\x6f\164\x20\x66\157\x75\156\144\x2e", $vhostTemplateName)); goto Eb761; e314e: $this->createNodejsSite($domainName, $nodejsVersion, $port, $siteUser, $siteUserPassword); goto b19df; b19df: $eventData = ["\163\151\x74\x65" => $domainName, "\x73\x69\x74\x65\125\x73\145\x72" => $siteUser, "\156\157\144\x65\x6a\163\x56\x65\162\x73\151\157\156" => $nodejsVersion, "\160\x6f\162\x74" => $port]; goto c3549; f6dd1: $nodejsVersion = $form->get("\156\157\144\x65\x6a\x73\126\x65\162\x73\151\157\x6e")->getData(); goto f12b2; dc544: return $response; goto bf997; F6ad3: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\x61\x6e\147\x65\x72", $this->translator->trans("\101\156\x20\145\x72\x72\x6f\x72\40\150\141\x73\40\157\143\x63\165\x72\x72\x65\x64\x2c\40\145\162\162\157\162\40\x6d\x65\163\x73\x61\x67\x65\72\40\45\145\x72\x72\x6f\x72\x4d\145\163\163\141\147\145\45", ["\x25\145\x72\162\x6f\162\115\145\163\163\141\x67\145\x25" => $e->getMessage()])); } goto aa150; Ce9fb: goto Ade1e; goto e4e03; aa150: Ade1e: goto d76e5; C603f: $this->formErrors = $this->getErrorMessages($form); goto Ce9fb; d76e5: } public function newStaticSite(Request $request) : Response { goto b6315; ff232: $response = $this->redirect($this->generateUrl("\143\154\160\x5f\163\x69\x74\x65\x73")); goto Ca45f; Bd573: f29e6: goto Fe0b3; Fe0b3: $user = $this->getUser(); goto B3352; da2a1: if (!(true === $request->isMethod("\120\117\x53\124"))) { goto A5f27; } goto a4f9a; b6315: $hasPermissions = $this->hasPermissions(); goto c647d; F3698: Ab05c: goto f6538; f3891: $response = $this->render("\x46\x72\157\x6e\x74\x65\x6e\x64\57\123\x69\164\x65\x2f\x4e\145\x77\57\x73\164\x61\x74\151\x63\56\x68\164\x6d\154\x2e\x74\x77\151\147", ["\165\x73\x65\162" => $user, "\x66\157\162\155" => $form->createView(), "\146\x6f\x72\155\x45\x72\162\x6f\x72\163" => $this->formErrors]); goto F3698; B3352: $form = $this->createStaticSiteForm(); goto da2a1; bfd11: if (!(false === is_null($response))) { goto b37cd; } goto fd1cb; f6538: return $response; goto E7fd9; Ca45f: goto Ab05c; goto Bd573; E6869: $response = $this->handleCreateStaticSiteForm($request, $form); goto bfd11; c647d: if (true === $hasPermissions) { goto f29e6; } goto ff232; a4f9a: $form->handleRequest($request); goto a3a9b; E0314: E8236: goto Ac55c; fd1cb: return $response; goto a58dd; a58dd: b37cd: goto E0314; Ac55c: A5f27: goto f3891; a3a9b: if (!(true === $form->isSubmitted())) { goto E8236; } goto E6869; E7fd9: } private function createStaticSiteForm() : Form { goto C638b; C638b: $form = $this->createForm("\x41\160\160\x5c\x46\x6f\162\x6d\x5c\x53\x69\x74\145\x4e\x65\x77\123\164\x61\164\x69\143\x54\171\x70\145", [], ["\141\x63\164\151\157\x6e" => $this->generateUrl("\143\154\160\137\x73\x69\164\x65\x5f\x73\164\141\164\151\x63\x5f\x6e\x65\x77"), "\155\x65\164\150\157\144" => "\x50\x4f\123\x54", "\x61\x74\x74\x72" => []]); goto D22a1; ee2c1: return $form; goto d7c80; D22a1: $form->add("\x73\165\x62\155\x69\x74", SubmitType::class, ["\x61\x74\164\162" => ["\143\x6c\141\x73\163" => "\x62\164\x6e\x20\142\x74\x6e\x2d\x6c\147\x20\x62\x74\x6e\x2d\x62\x6c\165\x65"], "\154\141\x62\x65\154" => "\x43\162\x65\141\164\x65"]); goto ee2c1; d7c80: } private function handleCreateStaticSiteForm(Request $request, Form $form) { goto a7088; b8123: E8fe9: goto af4eb; a7088: if (true === $form->isValid()) { goto E8fe9; } goto Ffdaf; Ffdaf: $this->formErrors = $this->getErrorMessages($form); goto d1201; cec45: C78df: goto b8c7b; af4eb: try { goto c2d5c; fac26: $vhostTemplateName = self::STATIC_SITE_VHOST_TEMPLATE_NAME; goto D027d; E20bb: $this->createStaticSite($domainName, $siteUser, $siteUserPassword); goto B36db; e11a9: $siteUserPassword = $form->get("\x73\x69\164\145\125\163\x65\162\x50\141\163\163\x77\157\162\x64")->getData(); goto fac26; D107c: bcf55: goto Cedd0; c82d2: $domainName = $form->get("\x64\x6f\x6d\x61\151\156\x4e\x61\155\x65")->getData(); goto f4aff; f4aff: $siteUser = $form->get("\x73\x69\164\x65\x55\x73\x65\162")->getData(); goto e11a9; D7191: throw new \Exception(sprintf("\126\x68\157\x73\x74\40\x74\x65\155\160\x6c\141\164\x65\x20\x22\45\163\42\x20\156\x6f\x74\x20\x66\x6f\x75\x6e\x64\x2e", $vhostTemplateName)); goto df129; Cedd0: $user = $this->getUser(); goto E20bb; B36db: $eventData = ["\x73\x69\164\x65" => $domainName, "\x73\151\164\x65\125\163\145\162" => $siteUser]; goto a0260; a1583: $response = $this->redirect($this->generateUrl("\143\x6c\160\x5f\163\x69\x74\x65\x73")); goto febd4; C05fa: if (false === is_null($vhostTemplateEntity)) { goto bcf55; } goto D7191; D027d: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto C05fa; B180d: $session->getFlashBag()->set("\163\x75\x63\143\x65\163\163", $this->translator->trans("\123\151\x74\x65\40\x68\x61\163\x20\x62\145\x65\156\40\x63\162\x65\141\x74\x65\x64\x2e")); goto a1583; a0260: EventQueue::addEvent(EventQueue::EVENT_SITE_STATIC_CREATE, $user, $eventData, $request); goto B180d; c2d5c: $session = $request->getSession(); goto c82d2; f6cec: B5035: goto c2153; febd4: return $response; goto f6cec; df129: goto B5035; goto D107c; c2153: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\141\156\x67\145\162", $this->translator->trans("\101\156\x20\145\162\x72\x6f\x72\40\150\141\x73\x20\x6f\143\143\x75\162\x72\145\x64\x2c\40\x65\x72\162\x6f\162\40\x6d\145\163\x73\x61\x67\x65\72\40\45\145\162\162\x6f\162\x4d\x65\163\x73\141\147\145\x25", ["\x25\x65\162\162\x6f\162\115\x65\x73\x73\x61\147\x65\45" => $e->getMessage()])); } goto cec45; d1201: goto C78df; goto b8123; b8c7b: } public function newPhpSite(Request $request) : Response { goto Dff30; af123: $response = $this->handleCreatePhpSiteForm($request, $form); goto b6a0e; De981: Fce45: goto A7ffe; A92d1: if (!(true === $request->isMethod("\120\117\x53\x54"))) { goto dd681; } goto ebc12; c2290: goto Fce45; goto af29c; ebc12: $form->handleRequest($request); goto Dbc6a; C64e7: return $response; goto A3a59; Dbc6a: if (!(true === $form->isSubmitted())) { goto Ae015; } goto af123; ed5b6: dd681: goto C803d; C803d: $response = $this->render("\x46\x72\x6f\x6e\x74\x65\x6e\x64\x2f\x53\151\164\145\x2f\116\x65\x77\57\x70\x68\160\x2e\150\164\155\x6c\x2e\x74\x77\151\x67", ["\x75\163\x65\162" => $user, "\x66\157\x72\x6d" => $form->createView(), "\x66\x6f\x72\x6d\x45\x72\162\157\162\x73" => $this->formErrors]); goto De981; F2984: $response = $this->redirect($this->generateUrl("\x63\x6c\160\137\163\x69\x74\145\x73")); goto c2290; Df581: if (true === $hasPermissions) { goto Fed20; } goto F2984; d63fd: $user = $this->getUser(); goto da964; da964: $form = $this->createPhpSiteForm(); goto A92d1; b6a0e: if (!(false === is_null($response))) { goto Bbcb6; } goto C64e7; A3a59: Bbcb6: goto c2936; c2936: Ae015: goto ed5b6; A7ffe: return $response; goto C0f4a; Dff30: $hasPermissions = $this->hasPermissions(); goto Df581; af29c: Fed20: goto d63fd; C0f4a: } private function createPhpSiteForm() : Form { goto f8686; e3762: return $form; goto f5755; dd5f5: $form->add("\x73\165\x62\x6d\x69\x74", SubmitType::class, ["\141\x74\164\162" => ["\143\154\x61\163\x73" => "\142\x74\156\40\142\164\156\x2d\x6c\147\x20\142\164\x6e\x2d\x62\154\165\145"], "\154\x61\x62\x65\x6c" => "\x43\x72\145\141\164\145"]); goto e3762; f8686: $form = $this->createForm("\101\160\x70\134\x46\157\x72\x6d\x5c\x53\151\x74\145\x4e\x65\167\120\x68\160\124\x79\x70\145", [], ["\x61\143\x74\151\x6f\156" => $this->generateUrl("\x63\154\x70\137\163\x69\x74\145\x5f\x70\x68\x70\x5f\156\145\x77"), "\x6d\145\164\x68\x6f\x64" => "\x50\117\x53\x54", "\141\x74\164\162" => []]); goto dd5f5; f5755: } private function handleCreatePhpSiteForm(Request $request, Form $form) { goto C212e; C212e: if (true === $form->isValid()) { goto Bbf5b; } goto aea97; aea97: $this->formErrors = $this->getErrorMessages($form); goto f4469; Cd917: Ee8a0: goto ec64e; E12f3: Bbf5b: goto a3345; f4469: goto Ee8a0; goto E12f3; a3345: try { goto B9e50; F6578: $varnishCacheSettings = (array) json_decode($vhostTemplateEntity->getVarnishCacheSettings(), true); goto f2133; Adb34: throw new \Exception(sprintf("\126\150\x6f\163\x74\x20\164\x65\155\x70\154\x61\x74\145\40\42\45\163\42\40\x6e\157\164\x20\146\157\165\x6e\x64\56", $vhostTemplateName)); goto e7f85; Ac6af: $varnishCacheSettings = []; goto A1dc3; eb78a: $rootDirectory = $domainName; goto C996b; B9e50: $session = $request->getSession(); goto Baa38; Be815: $phpVersion = $form->get("\x70\150\160\126\145\162\x73\x69\157\x6e")->getData(); goto D9b15; Baa38: $vhostTemplateName = $form->get("\x61\x70\160\x6c\151\143\141\x74\151\157\x6e")->getData(); goto B9bc3; E5973: $session->getFlashBag()->set("\163\165\x63\x63\145\x73\163", $this->translator->trans("\x53\151\164\145\40\x68\141\163\x20\x62\145\145\156\x20\x63\x72\145\x61\x74\145\x64\x2e")); goto E4457; B9bc3: $domainName = $form->get("\x64\x6f\x6d\141\151\x6e\116\x61\x6d\145")->getData(); goto Be815; b27f1: $user = $this->getUser(); goto eb78a; f2133: ae4c2: goto Cee74; A1dc3: if (!(false === empty($vhostTemplateEntity->getVarnishCacheSettings()))) { goto ae4c2; } goto F6578; dc6ff: if (false === is_null($vhostTemplateEntity)) { goto B910c; } goto Adb34; e7f85: goto ee2e1; goto d9491; E4457: $response = $this->redirect($this->generateUrl("\143\154\x70\137\163\151\164\x65\x73")); goto ce22d; ce22d: return $response; goto B679f; Dc72f: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto dc6ff; d9491: B910c: goto b27f1; aadd9: EventQueue::addEvent(EventQueue::EVENT_SITE_PHP_CREATE, $user, $eventData, $request); goto E5973; C996b: if (!(false === empty($vhostTemplateEntity->getRootDirectory()))) { goto E22d6; } goto e0d45; B679f: ee2e1: goto f058a; Cee74: $this->createPhpSite($domainName, $rootDirectory, $phpVersion, $vhostTemplateName, $siteUser, $siteUserPassword, $varnishCacheSettings); goto Ed757; C2ff9: E22d6: goto Ac6af; d7063: $siteUserPassword = $form->get("\163\151\164\x65\125\163\x65\162\120\141\163\163\167\x6f\x72\x64")->getData(); goto Dc72f; e0d45: $rootDirectory = sprintf("\45\163\57\x25\x73", $rootDirectory, ltrim(rtrim($vhostTemplateEntity->getRootDirectory(), "\57"), "\x2f")); goto C2ff9; Ed757: $eventData = ["\163\151\x74\145" => $domainName, "\x76\150\157\163\164\x54\x65\x6d\x70\154\141\164\x65\116\x61\x6d\145" => $vhostTemplateName, "\160\150\x70\x56\x65\x72\163\x69\x6f\x6e" => $phpVersion, "\163\151\x74\x65\125\163\145\x72" => $siteUser]; goto aadd9; D9b15: $siteUser = $form->get("\163\x69\164\145\x55\163\x65\162")->getData(); goto d7063; f058a: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\141\156\x67\x65\x72", $this->translator->trans("\x41\x6e\x20\x65\162\162\x6f\162\x20\x68\141\163\x20\x6f\143\x63\x75\162\x72\145\x64\54\40\145\x72\162\x6f\x72\x20\155\145\x73\x73\x61\x67\x65\72\40\x25\145\162\x72\x6f\x72\x4d\145\163\163\141\x67\x65\45", ["\x25\x65\x72\162\157\x72\115\x65\163\163\x61\x67\145\x25" => $e->getMessage()])); } goto Cd917; ec64e: } public function newWordPressSite(Request $request) : Response { goto Da3e6; D86cc: $response = $this->render("\106\162\x6f\x6e\x74\145\x6e\x64\x2f\x53\x69\x74\145\x2f\x4e\x65\167\x2f\167\157\162\144\x70\162\x65\x73\163\x2e\x68\164\x6d\154\x2e\164\167\x69\147", ["\x75\x73\145\x72" => $user, "\146\157\162\155" => $form->createView(), "\146\157\x72\155\x45\x72\162\157\162\x73" => $this->formErrors]); goto bc2fa; b8271: f4680: goto D86cc; fddf9: if (true === $hasPermissions) { goto f35fe; } goto F88fc; A8c33: if (!(true === $request->isMethod("\120\x4f\x53\x54"))) { goto f4680; } goto efec9; c3c26: $response = $this->handleCreateWordPressSiteForm($request, $form); goto B5219; efec9: $form->handleRequest($request); goto ac58c; F88fc: $response = $this->redirect($this->generateUrl("\143\x6c\160\x5f\163\x69\x74\x65\x73")); goto a804e; ac58c: if (!(true === $form->isSubmitted())) { goto C8f0b; } goto c3c26; Ae38b: $form = $this->createWordPressSiteForm(); goto A8c33; a804e: goto E69bf; goto f0903; B5219: if (!(false === is_null($response))) { goto a5373; } goto C21a5; b2dd6: $user = $this->getUser(); goto Ae38b; e7361: return $response; goto De539; Ce856: a5373: goto D5301; bc2fa: E69bf: goto e7361; f0903: f35fe: goto b2dd6; Da3e6: $hasPermissions = $this->hasPermissions(); goto fddf9; D5301: C8f0b: goto b8271; C21a5: return $response; goto Ce856; De539: } private function createWordPressSiteForm() : Form { goto f15c0; Afd3b: return $form; goto c2260; D027a: $form->add("\x73\x75\x62\155\x69\x74", SubmitType::class, ["\x61\x74\x74\162" => ["\x63\154\x61\163\x73" => "\x62\x74\156\x20\142\x74\x6e\55\x6c\147\x20\142\164\156\x2d\x62\154\165\145"], "\154\141\x62\145\154" => "\103\x72\145\x61\164\145"]); goto Afd3b; f15c0: $form = $this->createForm("\101\x70\x70\x5c\x46\157\x72\x6d\134\123\151\x74\145\116\x65\x77\127\x6f\x72\x64\x50\x72\145\x73\163\124\x79\x70\145", [], ["\141\x63\x74\151\x6f\156" => $this->generateUrl("\143\x6c\x70\137\x73\151\x74\145\x5f\x77\157\162\144\160\x72\x65\163\163\x5f\x6e\145\167"), "\x6d\145\164\150\x6f\x64" => "\x50\x4f\123\124", "\141\164\x74\x72" => ["\x69\144" => "\156\145\x77\x2d\167\157\x72\x64\160\x72\x65\x73\x73\x2d\163\x69\x74\x65\55\146\x6f\x72\x6d"]]); goto D027a; c2260: } private function handleCreateWordPressSiteForm(Request $request, Form $form) { goto Cb715; Ca51d: F1590: goto e0b7f; Cb715: if (true === $form->isValid()) { goto F1590; } goto F05ef; e0b7f: try { goto aa806; Dddcb: A654a: goto Ed585; a3f1d: $databaseManager->createUser($databaseUserEntity); goto B0350; d9ce1: return $response; goto C006b; bdf35: $databaseEntity->setSite($siteEntity); goto E960e; E87aa: $databaseEntity->setDatabaseServer($activeDatabaseServerEntity); goto fb765; Acb84: $siteEntity->addDatabase($databaseEntity); goto Ef67d; Fd95a: $domainName = $form->get("\144\x6f\155\141\x69\x6e\116\x61\155\145")->getData(); goto b531b; A89fa: $siteCredentials = [$this->translator->trans("\x53\x69\164\x65") => [$this->translator->trans("\x49\x50\40\x41\144\x64\x72\145\163\x73") => $instance->getIpv4PublicIp(), $this->translator->trans("\x44\x6f\x6d\x61\x69\156\40\x4e\x61\155\145") => sprintf("\x68\x74\164\160\163\x3a\57\57\x25\x73", $domainName), $this->translator->trans("\123\151\x74\145\x20\x55\163\145\x72") => $siteUser, $this->translator->trans("\x50\x61\x73\163\167\x6f\x72\x64") => $siteUserPassword]]; goto e07ab; Ed585: $session->set("\x73\151\x74\145\x43\162\145\x64\x65\156\164\151\141\x6c\x73", $siteCredentials); goto E59d7; ebfa4: $siteUser = $form->get("\x73\151\x74\x65\x55\163\145\x72")->getData(); goto c23db; a5849: $siteCredentials["\127\157\162\x64\120\x72\145\163\163"] = [$this->translator->trans("\x41\144\155\151\156\x20\105\55\x4d\x61\151\x6c") => $adminEmail, $this->translator->trans("\x41\x64\155\151\156\x20\125\163\145\x72\40\116\141\155\x65") => $adminUserName, $this->translator->trans("\x41\x64\x6d\x69\156\40\120\x61\163\x73\167\x6f\x72\x64") => $adminPassword, $this->translator->trans("\x41\x64\155\x69\156\40\125\x72\x6c") => sprintf("\x68\x74\164\160\x73\72\57\57\x25\163\57\x77\160\x2d\141\x64\x6d\151\156\57", rtrim($domainName, "\57"))]; goto Dddcb; fb765: $databaseEntity->setName($databaseName); goto bdf35; B29a8: $title = $form->get("\163\x69\164\145\124\151\x74\x6c\145")->getData(); goto Af78a; dd40c: $varnishCacheSettings = (array) json_decode($vhostTemplateEntity->getVarnishCacheSettings(), true); goto f38f4; B3e39: $adminEmail = $form->get("\141\x64\x6d\151\x6e\x45\155\141\x69\154")->getData(); goto Fad7e; E960e: $databaseUserEntity = $this->databaseUserEntityManager->createEntity(); goto D9b03; f35b2: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto Aa96d; a5b6f: $url = sprintf("\150\x74\164\x70\163\x3a\57\x2f\x25\x73", $siteEntity->getDomainName()); goto B29a8; D9b03: $databaseUserEntity->setUserName($databaseUserName); goto B4df1; f38f4: a441c: goto e5818; E59d7: $eventData = ["\163\151\164\x65" => $domainName, "\163\x69\164\145\125\x73\x65\162" => $siteUser]; goto C777c; de697: $session = $request->getSession(); goto Fd95a; Fad7e: $isMultiSite = $form->get("\x6d\x75\x6c\x74\151\123\x69\x74\145")->getData(); goto Eea76; e5818: $siteEntity = $this->createPhpSite($domainName, $domainName, $phpVersion, self::WORDPRESS_VHOST_TEMPLATE_NAME, $siteUser, $siteUserPassword, $varnishCacheSettings); goto f35b2; Af78a: $adminUserName = $form->get("\141\x64\155\151\x6e\125\163\145\162\x4e\x61\x6d\145")->getData(); goto d0157; c51fa: $databaseUserPassword = PasswordGenerator::generate(self::PASSWORD_LENGTH); goto a5b6f; a6dd3: $databaseUserEntity->setDatabase($databaseEntity); goto B539c; Ae189: $databaseEntity = $this->databaseEntityManager->createEntity(); goto E87aa; e6f4b: $siteCredentials[$this->translator->trans("\x44\141\164\141\x62\x61\x73\145")] = [$this->translator->trans("\110\157\x73\164") => $activeDatabaseServerEntity->getHost(), $this->translator->trans("\120\x6f\x72\x74") => $activeDatabaseServerEntity->getPort(), $this->translator->trans("\104\x61\164\141\142\x61\x73\x65\x20\116\x61\155\x65") => $databaseName, $this->translator->trans("\x44\141\x74\x61\x62\141\163\x65\40\125\163\x65\162\x20\x4e\x61\155\145") => $databaseUserName, $this->translator->trans("\x44\x61\164\x61\142\x61\x73\145\40\x55\x73\x65\x72\40\x50\141\163\163\167\x6f\162\144") => $databaseUserPassword]; goto a5849; B6d7b: $phpVersion = $vhostTemplateEntity->getPhpVersion(); goto D8437; D8437: $varnishCacheSettings = []; goto f0cf3; D4b93: $databaseUserName = $this->getUniqueDatabaseUserName($generatedName); goto c51fa; b531b: $generatedName = $this->generateNameFromDomainName($domainName); goto ebfa4; c23db: $siteUserPassword = $form->get("\163\151\164\145\125\x73\x65\x72\120\x61\x73\163\x77\x6f\162\144")->getData(); goto F1f40; Eea76: $activeDatabaseServerEntity = $this->databaseServerEntityManager->getActiveDatabaseServer(); goto Ae189; aa806: $user = $this->getUser(); goto de697; A52c9: $databaseUserEntity->setPermissions(DatabaseUserEntity::PERMISSIONS_READ_WRITE); goto a6dd3; d0157: $adminPassword = $form->get("\x61\x64\x6d\x69\156\x50\141\163\x73\x77\157\x72\144")->getData(); goto B3e39; B539c: $databaseEntity->addUser($databaseUserEntity); goto Acb84; C777c: EventQueue::addEvent(EventQueue::EVENT_SITE_WORDPRESS_CREATE, $user, $eventData, $request); goto bb724; bb724: $response = $this->redirect($this->generateUrl("\143\154\160\x5f\x73\151\164\145\x5f\x77\157\x72\144\x70\162\x65\163\x73\x5f\x69\x6e\163\x74\141\154\x6c\x65\x64")); goto d9ce1; F1f40: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::WORDPRESS_VHOST_TEMPLATE_NAME); goto B6d7b; c4a3f: $this->installWordPress($isMultiSite, $url, $title, $adminUserName, $adminPassword, $adminEmail, $siteEntity, $activeDatabaseServerEntity, $databaseEntity, $databaseUserEntity); goto e6f4b; e07ab: if (!(false === is_null($siteEntity))) { goto A654a; } goto Ce340; Aa96d: $instance = $request->attributes->get("\x69\x6e\x73\x74\141\x6e\x63\x65"); goto A89fa; B0350: $this->siteEntityManager->updateEntity($siteEntity); goto c4a3f; Ce340: $databaseName = $this->getUniqueDatabaseName($generatedName); goto D4b93; b77b3: $databaseManager->createDatabase($databaseEntity); goto a3f1d; f0cf3: if (!(false === empty($vhostTemplateEntity->getVarnishCacheSettings()))) { goto a441c; } goto dd40c; B4df1: $databaseUserEntity->setPassword(Crypto::encrypt($databaseUserPassword)); goto A52c9; Ef67d: $databaseManager = new DatabaseManager($activeDatabaseServerEntity); goto b77b3; C006b: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\141\x6e\147\x65\x72", $this->translator->trans("\101\156\x20\x65\162\162\x6f\x72\40\x68\141\x73\x20\157\143\x63\165\x72\162\145\144\54\40\145\x72\x72\x6f\x72\40\x6d\x65\163\x73\141\147\x65\72\40\x25\x65\162\x72\157\162\115\x65\163\x73\141\x67\145\x25", ["\x25\x65\x72\x72\x6f\x72\x4d\145\x73\x73\x61\x67\x65\45" => $e->getMessage()])); } goto a8e0c; a8e0c: bbd73: goto C61bb; F05ef: $this->formErrors = $this->getErrorMessages($form); goto Ba027; Ba027: goto bbd73; goto Ca51d; C61bb: } private function installWordPress(bool $isMultiSite, string $url, string $title, string $adminUserName, string $adminPassword, string $adminEmail, SiteEntity $siteEntity, DatabaseServerEntity $databaseServerEntity, DatabaseEntity $databaseEntity, DatabaseUserEntity $databaseUserEntity) : void { goto A2d93; E49fc: $wordPressInstaller->installCore($isMultiSite, $url, $title, $adminUserName, $adminPassword, $adminEmail); goto bb032; e7e54: $wordPressInstaller->resetPermissions(); goto Afad4; Da047: Acb45: goto acbd5; f17b0: foreach ($this->wordPressMultiSiteConfigValues as $key => $config) { $wordPressInstaller->setConfigValue($key, $config["\166\141\154\165\145"], $config["\x72\141\167"]); d56f8: } goto efe11; dad2d: e1241: goto e7e54; D0877: $wordPressInstaller->downloadAndExtractLatestVersion(); goto d70ea; efa6a: $databaseName = $databaseEntity->getName(); goto c885d; cab4a: $this->wordPressMultiSiteConfigValues["\x44\x4f\x4d\101\x49\116\x5f\103\125\122\x52\x45\116\124\x5f\x53\x49\x54\x45"]["\x76\x61\x6c\165\145"] = $siteEntity->getDomainName(); goto f17b0; c6787: $databaseUserPassword = Crypto::decrypt($databaseUserEntity->getPassword()); goto b1f2d; acbd5: if (!(true === $isMultiSite)) { goto e1241; } goto cab4a; efe11: Fc2b9: goto dad2d; c885d: $databaseUserName = $databaseUserEntity->getUserName(); goto c6787; b1f2d: $wordPressInstaller = new WordPressInstaller($siteEntity); goto D0877; A2d93: $databaseHost = sprintf("\45\x73\x3a\45\163", $databaseServerEntity->getHost(), $databaseServerEntity->getPort()); goto efa6a; d70ea: $wordPressInstaller->createConfig($databaseHost, $databaseName, $databaseUserName, $databaseUserPassword); goto E49fc; bb032: foreach ($this->wordPressDefaultConfigValues as $key => $config) { $wordPressInstaller->setConfigValue($key, $config["\166\141\x6c\x75\145"], $config["\162\141\x77"]); a916d: } goto Da047; Afad4: } private function createPhpSite(string $domainName, string $rootDirectory, string $phpVersion, string $vhostTemplateName, string $siteUser, string $siteUserPassword, array $varnishCacheSettings = []) : SiteEntity { goto fd071; B4688: E79d6: goto E9b6d; Be749: $siteEntity->setRootDirectory($rootDirectory); goto De83c; Cad74: $vhostTemplate->resetProcessors(); goto a2a6a; ea9ef: $phpSite->setRootDirectory($siteEntity->getRootDirectory()); goto a1377; af316: $siteEntity->setVarnishCache(true); goto B48a6; A5b99: $constraintViolationList->addAll($phpSettingsConstraints); goto ce3bb; e4d85: $phpSettingsEntity->setSite($siteEntity); goto A0357; f9e44: $subjectAlternativeNames[] = $registrableDomain; goto d9c78; bd6ba: $siteEntity->setUserPassword($siteUserPassword); goto Be749; e704b: if (!(false === is_null($subdomain) && "\167\167\x77" == $subdomain)) { goto Fe587; } goto f9e44; e9da1: if (!(true === $varnishCache)) { goto A7841; } goto d8b64; d2de9: $phpSite->setVarnishCacheSettings($varnishCacheSettings); goto af28c; B48a6: d5c71: goto B4710; C41ed: $subjectAlternativeNames[] = sprintf("\167\x77\x77\x2e\x25\x73", $domainName); goto Aebc9; d62da: $phpSiteCreator->reloadPhpFpmService(); goto e9da1; Bb884: $phpSettingsConstraints = $this->validator->validate($phpSettingsEntity); goto a9e2c; bcaf3: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto F1349; Ae819: A51eb: goto ed256; E8e77: $subjectAlternativeNames = []; goto C42ba; bce53: throw new \Exception(implode("\x3b\40", $errorMessages)); goto B8b8d; F5130: $certificateEntity = $this->certificateEntityManager->createEntity(); goto F73b4; E1d7e: $certificateEntity->setDefaultCertificate(true); goto bcaf3; ff20e: $certificateEntity->setCertificate($selfSignedCertificate); goto F9a51; E9b6d: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\56\x2e\57\56\56\57\56\x2e\x2f\162\145\x73\157\x75\162\143\145\x73\57\x6e\147\151\156\x78\57\x76\150\157\x73\164\x5f\x74\145\155\x70\154\x61\x74\x65\57\162\145\x64\x69\162\x65\x63\164\x2d\150\x74\x74\160\63"); goto Ae819; C6c89: $siteEntity->setType(SiteEntity::TYPE_PHP); goto E8017; B948a: $phpSiteCreator->createUser(); goto e5f51; Bfb15: $defaultVarnishCacheSettings = ["\145\x6e\x61\x62\x6c\145\144" => false, "\163\x65\162\166\x65\x72" => self::VARNISH_CACHE_SERVER, "\143\141\x63\x68\x65\x54\x61\x67\120\162\145\x66\x69\x78" => substr(md5(time()), 0, 4)]; goto C41c2; a4257: $rsaKeyGenerator = new RsaKeyGenerator(); goto A2d27; F9a51: $siteEntity->setCertificate($certificateEntity); goto dd660; ead7e: Bd179: goto b7888; d002c: $vhostTemplate = new PhpVhostTemplate($phpSite); goto c51f9; F55a0: $phpSite->setDomainName($domainName); goto d9ac6; ed256: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto c627c; B4710: if (!(true === is_null($subdomain) || "\x77\167\167" == $subdomain)) { goto B8fbd; } goto Ce37a; dd660: $phpSite = new PhpSite(); goto f122a; Fa7f0: $phpSite->setUserPassword($siteEntity->getUserPassword()); goto F55a0; e99ee: $phpSiteCreator->createIndexPhp(); goto F2a38; F73b4: $certificateEntity->setSite($siteEntity); goto a4257; F5f36: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto B9fef; bcd7c: $constraintViolationList = new ConstraintViolationList(); goto Bf580; c33f9: $phpSettingsEntity = new PhpSettingsEntity(); goto Cdcbc; e972f: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto d986f; ddb35: $siteEntity->setVhostTemplate($vhostTemplate); goto c33f9; F9bed: $csr = $csrGenerator->generate(); goto Aa6d0; Bf818: $phpSiteCreator->createNginxVhost(); goto f2c8a; f122a: $phpSite->setUser($siteEntity->getUser()); goto Fa7f0; Aebc9: E6d71: goto e704b; f2c8a: $phpSiteCreator->reloadNginxService(); goto E934c; C42ba: if (!(true === is_null($subdomain))) { goto E6d71; } goto C41ed; ac044: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\56\57\x2e\56\x2f\x2e\56\57\x72\145\163\157\x75\162\143\x65\163\57\156\147\x69\x6e\170\57\166\x68\x6f\163\x74\137\164\145\155\x70\154\141\164\x65\x2f\x72\x65\144\151\x72\145\x63\x74"); goto Ae589; Df7f4: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto B6efd; d9c78: Fe587: goto F5f36; Bf580: $constraintViolationList->addAll($siteConstraints); goto A5b99; F2a38: $phpSiteCreator->createPrivateKeyAndCertificate(); goto e47bc; ce3bb: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto bce53; Aa6d0: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto E1d7e; c627c: if (!(false === empty($redirectionVhostTemplate))) { goto Bd179; } goto f41d2; cf09b: $siteEntity->setUser($siteUser); goto bd6ba; A2d27: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto E8e77; b7888: B8fbd: goto ddb35; E8017: $siteEntity->setDomainName($domainName); goto cf09b; e1523: $subdomain = false === empty($subdomain) ? $subdomain : null; goto df856; C41c2: $varnishCacheSettings = array_merge($defaultVarnishCacheSettings, $varnishCacheSettings); goto E7a8f; ce780: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto e972f; e47bc: $phpSiteCreator->createPhpFpmPool(); goto d62da; B8b8d: bcb83: goto F5130; Ae589: goto A51eb; goto B4688; Cdcbc: $siteEntity->setPhpSettings($phpSettingsEntity); goto E78bf; e5f51: $phpSiteCreator->createRootDirectory(); goto F3223; f41d2: $vhostTemplate = sprintf("\45\163\45\x73", $redirectionVhostTemplate, $vhostTemplate); goto ead7e; a9e2c: if (!(count($siteConstraints) || count($phpSettingsConstraints))) { goto bcb83; } goto bcd7c; a2a6a: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto ce780; d986f: $vhostTemplate->build(); goto e6b3c; C55e6: return $siteEntity; goto Dac06; Be3ed: $subdomain = $resolvedDomainName->subDomain()->toString(); goto e1523; fd071: $varnishCache = false === empty($varnishCacheSettings) ? true : false; goto d8497; bde54: $phpSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto E68f1; d8497: $rootDirectory = trim(rtrim(ltrim($rootDirectory, "\57")), "\57"); goto E4ff4; B6efd: $siteEntity = $this->siteEntityManager->createEntity(); goto C6c89; df856: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto Df7f4; E4ff4: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto a99f4; a1377: $phpSite->setCertificate($certificateEntity); goto A5008; E68f1: $phpSiteCreator = new PhpSiteCreator($phpSite); goto B948a; Ce37a: if (true === isset($_ENV["\101\120\120\x5f\110\x54\124\x50\x33"]) && "\x74\x72\165\x65" === $_ENV["\x41\x50\x50\x5f\x48\x54\x54\x50\63"]) { goto E79d6; } goto ac044; B9fef: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto F9bed; c51f9: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto Cad74; E7a8f: $phpSiteCreator->createVarnishCacheStructure($varnishCacheSettings); goto d2de9; d9ac6: $phpSite->setRegistrableDomain($registrableDomain); goto Cb64d; A5008: $phpSite->setPhpSettings($phpSettingsEntity); goto bde54; af28c: A7841: goto Bf818; E934c: $phpSiteCreator->resetPermissions(); goto d002c; De83c: if (!(false === empty($varnishCache))) { goto d5c71; } goto af316; F3223: $phpSiteCreator->createLogrotateFile(); goto e99ee; d8b64: $phpSite->setVarnishCache(true); goto Bfb15; e6b3c: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto E5970; A0357: $siteConstraints = $this->validator->validate($siteEntity); goto Bb884; E78bf: $phpSettingsEntity->setPhpVersion($phpVersion); goto e4d85; Cb64d: $phpSite->setSubdomain($subdomain); goto ea9ef; a99f4: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto Be3ed; F1349: $certificateEntity->setCsr($csr); goto c5b3c; A477a: $this->siteEntityManager->updateEntity($siteEntity); goto C55e6; c5b3c: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto ff20e; E5970: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto A477a; Dac06: } private function createNodejsSite(string $domainName, string $nodejsVersion, string $port, string $siteUser, string $siteUserPassword) : SiteEntity { goto a6cab; e1142: $nodejsSiteCreator->createLogrotateFile(); goto e05c0; A77b1: $vhostTemplate->resetProcessors(); goto A1d3c; f6a20: if (!(true === is_null($subdomain))) { goto C65d3; } goto A02d6; cc4b1: $siteConstraints = $this->validator->validate($siteEntity); goto Ad86d; ac690: if (true === isset($_ENV["\x41\120\x50\137\110\124\124\120\x33"]) && "\x74\162\x75\x65" === $_ENV["\101\x50\120\x5f\x48\124\124\x50\63"]) { goto C688b; } goto Fe727; e2e7f: if (!(false === is_null($subdomain) && "\x77\x77\167" == $subdomain)) { goto Ed77f; } goto dd869; b6ced: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto Ec429; Eeb3a: $siteEntity->setType(SiteEntity::TYPE_NODEJS); goto B2319; F3940: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto D65a2; F444c: $subjectAlternativeNames = []; goto f6a20; b6598: $nodejsSettingsEntity->setSite($siteEntity); goto cc4b1; E532d: $rsaKeyGenerator = new RsaKeyGenerator(); goto Ba967; A5e59: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto d6898; D0057: $csr = $csrGenerator->generate(); goto b388e; Ec429: $certificateEntity->setCsr($csr); goto A5e59; c911f: $nodejsSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto E3954; d4448: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\56\57\56\56\x2f\56\x2e\57\x72\145\x73\157\x75\x72\x63\x65\163\57\x6e\147\151\x6e\x78\57\166\x68\157\163\x74\x5f\164\x65\155\160\154\x61\x74\145\x2f\162\x65\144\x69\x72\x65\143\x74\55\x68\164\164\160\63"); goto C51b5; ef1de: if (!(true === is_null($subdomain) || "\x77\x77\167" == $subdomain)) { goto F31c1; } goto ac690; Ef49c: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto Fc887; b0211: $nodejsSiteCreator->reloadNginxService(); goto a5e88; e05c0: $nodejsSiteCreator->createNvmDirectory(); goto D53fb; b50b6: if (!(false === empty($redirectionVhostTemplate))) { goto Dfdad; } goto ef992; a2a0d: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto b9a9b; Ad86d: $nodejsSettingsConstraints = $this->validator->validate($nodejsSettingsEntity); goto c863d; fb182: $certificateEntity->setSite($siteEntity); goto E532d; a6cab: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto a2a0d; c2407: $nodejsSettingsEntity->setPort($port); goto b6598; f232a: $constraintViolationList = new ConstraintViolationList(); goto Ae8bf; cd63a: $subdomain = false === empty($subdomain) ? $subdomain : null; goto ab508; b0b3a: $siteEntity->setUserPassword($siteUserPassword); goto Eb2fc; af893: $nodejsSite = new NodejsSite(); goto c29ee; d8414: f4ebc: goto d25a3; c7c67: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto b13a5; A07d5: $nodejsSiteCreator->createPrivateKeyAndCertificate(); goto C2fb7; Ba967: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto F444c; f4fe5: $vhostTemplate->build(); goto cb525; aab5a: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto D0057; Ae8bf: $constraintViolationList->addAll($siteConstraints); goto Fd92b; c75dc: $vhostTemplate = new StaticVhostTemplate($nodejsSite); goto A4d01; cb525: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto ace35; Efe47: $nodejsSiteCreator->createRootDirectory(); goto e1142; ace35: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto Bd22d; c863d: if (!(count($siteConstraints) || count($nodejsSettingsConstraints))) { goto f4ebc; } goto f232a; ab508: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::NODEJS_VHOST_TEMPLATE_NAME); goto F3940; d6898: $certificateEntity->setCertificate($selfSignedCertificate); goto B7863; ef5dd: $nodejsSite->setNodejsSettings($nodejsSettingsEntity); goto c911f; D65a2: $siteEntity = $this->siteEntityManager->createEntity(); goto Eeb3a; F2e67: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto aab5a; E3954: $nodejsSiteCreator = new NodejsSiteCreator($nodejsSite); goto Efe2f; Bd22d: $this->siteEntityManager->updateEntity($siteEntity); goto def56; d25a3: $certificateEntity = $this->certificateEntityManager->createEntity(); goto fb182; ca611: Ed77f: goto F2e67; ba54b: $nodejsSite->setRootDirectory($siteEntity->getRootDirectory()); goto Df9d0; B7863: $siteEntity->setCertificate($certificateEntity); goto af893; Fc887: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto f4fe5; Df9d0: $nodejsSite->setCertificate($certificateEntity); goto ef5dd; f31ca: $nodejsSite->setSubdomain($subdomain); goto ba54b; F6614: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto b50b6; A02d6: $subjectAlternativeNames[] = sprintf("\x77\167\x77\56\45\163", $domainName); goto c372b; B2319: $siteEntity->setDomainName($domainName); goto A7278; ec57d: $nodejsSettingsEntity->setNodejsVersion($nodejsVersion); goto c2407; dd869: $subjectAlternativeNames[] = $registrableDomain; goto ca611; Fd92b: $constraintViolationList->addAll($nodejsSettingsConstraints); goto c7c67; C2fb7: $nodejsSiteCreator->createNginxVhost(); goto b0211; Efe2f: $nodejsSiteCreator->createUser(); goto Efe47; b13a5: throw new \Exception(implode("\73\40", $errorMessages)); goto d8414; Fe727: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\56\56\57\x2e\56\57\56\56\57\162\x65\x73\157\x75\162\143\x65\x73\57\156\147\x69\x6e\170\57\x76\x68\157\163\x74\x5f\164\x65\155\x70\x6c\x61\164\x65\57\162\x65\x64\151\x72\x65\x63\x74"); goto B2276; b388e: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto F5b8c; a5e88: $nodejsSiteCreator->resetPermissions(); goto c75dc; F4070: C688b: goto d4448; B2276: goto C3c2c; goto F4070; ed901: $nodejsSite->setUserPassword($siteEntity->getUserPassword()); goto D245e; A1d3c: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto Ef49c; b9a9b: $subdomain = $resolvedDomainName->subDomain()->toString(); goto cd63a; A4d01: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto A77b1; A2684: F31c1: goto C41cf; Eb2fc: $siteEntity->setRootDirectory($domainName); goto ef1de; c29ee: $nodejsSite->setUser($siteEntity->getUser()); goto ed901; C41cf: $siteEntity->setVhostTemplate($vhostTemplate); goto e1446; e1446: $nodejsSettingsEntity = new NodejsSettingsEntity(); goto E4563; ef992: $vhostTemplate = sprintf("\45\x73\x25\163", $redirectionVhostTemplate, $vhostTemplate); goto a61e7; E4563: $siteEntity->setNodejsSettings($nodejsSettingsEntity); goto ec57d; def56: return $siteEntity; goto Aa309; F5b8c: $certificateEntity->setDefaultCertificate(true); goto b6ced; D53fb: $nodejsSiteCreator->installNodejs(); goto A07d5; b7331: $nodejsSite->setRegistrableDomain($registrableDomain); goto f31ca; c372b: C65d3: goto e2e7f; C51b5: C3c2c: goto F6614; D245e: $nodejsSite->setDomainName($domainName); goto b7331; A7278: $siteEntity->setUser($siteUser); goto b0b3a; a61e7: Dfdad: goto A2684; Aa309: } private function createPythonSite(string $domainName, string $pythonVersion, string $port, string $siteUser, string $siteUserPassword) : SiteEntity { goto fcd65; fcd65: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto F1b84; f3605: $vhostTemplate->resetProcessors(); goto c0717; E2744: $rsaKeyGenerator = new RsaKeyGenerator(); goto a08df; Ea303: goto c28b1; goto E9edf; cc22f: $siteEntity->setUser($siteUser); goto Ea106; e79de: a6350: goto eec90; ef94d: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto e5382; ef6ae: if (!(false === is_null($subdomain) && "\x77\x77\x77" == $subdomain)) { goto e7d79; } goto cfef5; E6ef8: ec021: goto D2caf; a4ba8: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto b9765; e5520: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\x2e\x2e\x2f\56\56\57\56\56\57\162\x65\x73\x6f\165\x72\x63\145\x73\x2f\x6e\147\151\156\x78\x2f\166\150\157\x73\x74\x5f\164\x65\x6d\x70\154\141\164\145\57\x72\x65\x64\151\162\x65\143\164"); goto Ea303; bef5f: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto E4952; ad1e8: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::PYTHON_VHOST_TEMPLATE_NAME); goto e3d25; edfa3: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto E090b; b091f: $pythonSettingsEntity->setPythonVersion($pythonVersion); goto f25ad; E9edf: e57a8: goto c61aa; Ea106: $siteEntity->setUserPassword($siteUserPassword); goto F2d44; e40ac: $pythonSite->setPythonSettings($pythonSettingsEntity); goto B0d1f; defa6: $pythonSite = new PythonSite(); goto ba341; fa678: $subdomain = $resolvedDomainName->subDomain()->toString(); goto ba6a1; d9558: $siteEntity = $this->siteEntityManager->createEntity(); goto bc100; f2216: Bc3c4: goto e79de; b81ab: $certificateEntity->setDefaultCertificate(true); goto a4ee4; cfef5: $subjectAlternativeNames[] = $registrableDomain; goto Bd198; edbdf: $subjectAlternativeNames = []; goto a3ede; B43bc: $pythonSite->setRegistrableDomain($registrableDomain); goto eed83; D2caf: $certificateEntity = $this->certificateEntityManager->createEntity(); goto F93fe; eec90: $siteEntity->setVhostTemplate($vhostTemplate); goto F81aa; ce37e: $pythonSiteCreator->resetPermissions(); goto a4e26; C0328: if (!(count($siteConstraints) || count($pythonSettingsConstraints))) { goto ec021; } goto Eb015; ea0fb: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto bc6a5; F93fe: $certificateEntity->setSite($siteEntity); goto E2744; cf07a: $pythonSiteCreator->createNginxVhost(); goto E08e0; a08df: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto edbdf; fcb69: $siteConstraints = $this->validator->validate($siteEntity); goto Ec432; B1682: if (!(true === is_null($subdomain) || "\167\x77\167" == $subdomain)) { goto a6350; } goto f0f16; e5382: throw new \Exception(implode("\x3b\x20", $errorMessages)); goto E6ef8; eed83: $pythonSite->setSubdomain($subdomain); goto f1cc1; E090b: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto a529a; f6552: $this->siteEntityManager->updateEntity($siteEntity); goto a4ba8; c8f99: $pythonSite->setDomainName($domainName); goto B43bc; F9f01: if (!(false === empty($redirectionVhostTemplate))) { goto Bc3c4; } goto Eb1c1; Dcc1f: c28b1: goto ef4bd; C2ad1: $subjectAlternativeNames[] = sprintf("\x77\167\167\56\x25\x73", $domainName); goto d6721; a4e26: $vhostTemplate = new PythonVhostTemplate($pythonSite); goto d080b; E08e0: $pythonSiteCreator->reloadNginxService(); goto ce37e; Eb8ad: $pythonSiteCreator->createRootDirectory(); goto Df93a; C6326: $siteEntity->setDomainName($domainName); goto cc22f; Bd198: e7d79: goto edfa3; Ec432: $pythonSettingsConstraints = $this->validator->validate($pythonSettingsEntity); goto C0328; f1cc1: $pythonSite->setRootDirectory($siteEntity->getRootDirectory()); goto Ba72c; D1666: $constraintViolationList->addAll($siteConstraints); goto d8b67; Eb015: $constraintViolationList = new ConstraintViolationList(); goto D1666; dd84b: $pythonSiteCreator->createUser(); goto Eb8ad; F81aa: $pythonSettingsEntity = new PythonSettingsEntity(); goto b7936; bc6a5: $certificateEntity->setCertificate($selfSignedCertificate); goto E2d32; F2d44: $siteEntity->setRootDirectory($domainName); goto B1682; bc100: $siteEntity->setType(SiteEntity::TYPE_PYTHON); goto C6326; f25ad: $pythonSettingsEntity->setPort($port); goto afbda; B1937: $pythonSiteCreator->createPrivateKeyAndCertificate(); goto cf07a; E2d32: $siteEntity->setCertificate($certificateEntity); goto defa6; c10ad: $certificateEntity->setCsr($csr); goto ea0fb; F1b84: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto fa678; e3d25: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto d9558; Df93a: $pythonSiteCreator->createLogrotateFile(); goto C5be3; E4952: $vhostTemplate->build(); goto fc348; f0f16: if (true === isset($_ENV["\x41\x50\120\137\110\x54\124\120\x33"]) && "\164\x72\x75\x65" === $_ENV["\101\x50\120\137\x48\124\x54\120\63"]) { goto e57a8; } goto e5520; afbda: $pythonSettingsEntity->setSite($siteEntity); goto fcb69; D328f: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto b81ab; d6721: C340c: goto ef6ae; d8b67: $constraintViolationList->addAll($pythonSettingsConstraints); goto ef94d; C8075: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto bef5f; a529a: $csr = $csrGenerator->generate(); goto D328f; D8e18: $pythonSite->setUserPassword($siteEntity->getUserPassword()); goto c8f99; c0717: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto C8075; fc348: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto f6552; a3ede: if (!(true === is_null($subdomain))) { goto C340c; } goto C2ad1; d080b: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto f3605; a4ee4: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto c10ad; ba6a1: $subdomain = false === empty($subdomain) ? $subdomain : null; goto ad1e8; b9765: return $siteEntity; goto aa7bf; ef4bd: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto F9f01; c61aa: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\56\57\56\56\x2f\x2e\56\57\x72\x65\163\157\x75\x72\143\145\163\x2f\x6e\147\x69\156\x78\57\x76\x68\157\x73\164\x5f\x74\x65\x6d\x70\154\x61\164\145\57\162\x65\x64\151\162\145\143\x74\x2d\150\164\x74\160\63"); goto Dcc1f; Eb1c1: $vhostTemplate = sprintf("\x25\163\x25\x73", $redirectionVhostTemplate, $vhostTemplate); goto f2216; b7936: $siteEntity->setPythonSettings($pythonSettingsEntity); goto b091f; ba341: $pythonSite->setUser($siteEntity->getUser()); goto D8e18; Ba72c: $pythonSite->setCertificate($certificateEntity); goto e40ac; B0d1f: $pythonSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto ac151; ac151: $pythonSiteCreator = new PythonSiteCreator($pythonSite); goto dd84b; C5be3: $pythonSiteCreator->writePythonVersionFile(); goto B1937; aa7bf: } private function createStaticSite(string $domainName, string $siteUser, string $siteUserPassword) : SiteEntity { goto Ce99f; a97af: $staticSite->setDomainName($domainName); goto b745d; Fc88a: $subjectAlternativeNames = []; goto c1fa6; F1248: $staticSite->setSubdomain($subdomain); goto d9f21; b745d: $staticSite->setRegistrableDomain($registrableDomain); goto F1248; Fd2b1: if (!(false === is_null($subdomain) && "\x77\167\167" == $subdomain)) { goto d0955; } goto a639e; Bb307: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto dcd12; d057d: $subjectAlternativeNames[] = sprintf("\x77\167\167\x2e\x25\x73", $domainName); goto Cd614; B6829: $siteEntity->setDomainName($domainName); goto C302b; Cda94: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto Fc88a; Eee2f: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto F0832; Fb1e6: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto ee0c3; A2b5f: afbfc: goto fe496; f6ce3: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto F0669; b16c5: $vhostTemplate->resetProcessors(); goto d2447; b1bed: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto d1196; Eb91b: $constraintViolationList = new ConstraintViolationList(); goto e4125; Fd8ef: $staticSiteCreator->reloadNginxService(); goto f400d; D6768: if (!(false === empty($redirectionVhostTemplate))) { goto Dd504; } goto Af2da; e617e: $staticSite->setCertificate($certificateEntity); goto F5991; B73d8: $certificateEntity->setSite($siteEntity); goto Ba7ef; ae0f8: $siteEntity->setUserPassword($siteUserPassword); goto De9a2; Cafa8: a2aab: goto Fe6f0; Bf826: $staticSiteCreator->createIndexHtml(); goto bb9bb; E2486: F58b3: goto B27a5; cecab: $vhostTemplate->build(); goto E061d; aa26e: $certificateEntity->setCertificate($selfSignedCertificate); goto e2e77; B27a5: $siteEntity->setVhostTemplate($vhostTemplate); goto D2394; F0832: $siteEntity = $this->siteEntityManager->createEntity(); goto C7bc6; A2e97: if (!(true === is_null($subdomain) || "\x77\167\x77" == $subdomain)) { goto F58b3; } goto fffd9; E6c7e: d0955: goto f6ce3; Ce99f: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto F9b9b; b4353: E073e: goto Ad927; aca99: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::STATIC_SITE_VHOST_TEMPLATE_NAME); goto Eee2f; c31ec: $staticSiteCreator->createUser(); goto fb4fb; C7bc6: $siteEntity->setType(SiteEntity::TYPE_STATIC); goto B6829; F5991: $staticSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto eb4e0; C302b: $siteEntity->setUser($siteUser); goto ae0f8; D8737: $subdomain = $resolvedDomainName->subDomain()->toString(); goto Da044; F9b9b: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto D8737; A0118: $staticSiteCreator->createLogrotateFile(); goto Bf826; dcd12: $this->siteEntityManager->updateEntity($siteEntity); goto e9bc0; a639e: $subjectAlternativeNames[] = $registrableDomain; goto E6c7e; Fb5d7: $staticSite->setUserPassword($siteEntity->getUserPassword()); goto a97af; c0491: $staticSite->setUser($siteEntity->getUser()); goto Fb5d7; A5751: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto aa26e; a3790: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto f76e6; eb4e0: $staticSiteCreator = new StaticSiteCreator($staticSite); goto c31ec; E56c9: goto E073e; goto A2b5f; e4125: $constraintViolationList->addAll($siteConstraints); goto Fb1e6; F7980: $vhostTemplate = new StaticVhostTemplate($staticSite); goto ec294; B76fb: if (!count($siteConstraints)) { goto a2aab; } goto Eb91b; De9a2: $siteEntity->setRootDirectory($domainName); goto A2e97; f400d: $staticSiteCreator->resetPermissions(); goto F7980; c2ffe: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\x2e\x2e\x2f\x2e\x2e\x2f\56\x2e\x2f\162\x65\x73\157\165\162\x63\x65\163\x2f\x6e\147\x69\x6e\x78\x2f\x76\x68\x6f\163\164\137\164\145\155\160\x6c\141\x74\145\57\162\145\144\151\162\145\143\x74"); goto E56c9; Cd614: F4d66: goto Fd2b1; f76e6: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto cecab; Fe6f0: $certificateEntity = $this->certificateEntityManager->createEntity(); goto B73d8; e9bc0: return $siteEntity; goto Fa5c9; d2447: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto a3790; d9f21: $staticSite->setRootDirectory($siteEntity->getRootDirectory()); goto e617e; e2e77: $siteEntity->setCertificate($certificateEntity); goto ff9fa; ec294: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto b16c5; fe496: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\56\x2e\x2f\56\56\x2f\56\x2e\57\x72\145\x73\157\x75\162\143\145\x73\57\156\147\151\156\170\57\x76\150\x6f\x73\x74\x5f\164\145\155\x70\x6c\141\x74\x65\x2f\x72\145\144\x69\162\145\x63\164\55\150\164\164\x70\63"); goto b4353; F0669: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto D1546; c1fa6: if (!(true === is_null($subdomain))) { goto F4d66; } goto d057d; ff9fa: $staticSite = new StaticSite(); goto c0491; E061d: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto Bb307; f1d71: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto d483a; D1546: $csr = $csrGenerator->generate(); goto f1d71; Ba7ef: $rsaKeyGenerator = new RsaKeyGenerator(); goto Cda94; bb9bb: $staticSiteCreator->createPrivateKeyAndCertificate(); goto ca6fe; fffd9: if (true === isset($_ENV["\101\120\120\137\x48\x54\x54\x50\x33"]) && "\164\x72\x75\x65" === $_ENV["\x41\120\x50\137\110\x54\124\120\x33"]) { goto afbfc; } goto c2ffe; e46ef: Dd504: goto E2486; d1196: $certificateEntity->setCsr($csr); goto A5751; Af2da: $vhostTemplate = sprintf("\x25\x73\x25\163", $redirectionVhostTemplate, $vhostTemplate); goto e46ef; d483a: $certificateEntity->setDefaultCertificate(true); goto b1bed; ca6fe: $staticSiteCreator->createNginxVhost(); goto Fd8ef; fb4fb: $staticSiteCreator->createRootDirectory(); goto A0118; Ad927: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto D6768; D2394: $siteConstraints = $this->validator->validate($siteEntity); goto B76fb; Da044: $subdomain = false === empty($subdomain) ? $subdomain : null; goto aca99; ee0c3: throw new \Exception(implode("\x3b\x20", $errorMessages)); goto Cafa8; Fa5c9: } private function createReverseProxySite(string $domainName, string $reverseProxyUrl, string $siteUser, string $siteUserPassword) : SiteEntity { goto b4d39; Ce3ce: $certificateEntity->setCertificate($selfSignedCertificate); goto F84b2; fc9ca: if (!count($siteConstraints)) { goto f0086; } goto ac7c0; dff38: if (!(true === is_null($subdomain))) { goto B51ee; } goto b12f2; F639d: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto f1069; D8767: $reversProxySiteCreator = new ReverseProxySiteCreator($reverseProxySite); goto B73d7; c330f: $reverseProxySite = new ReverseProxySite(); goto c63bb; Dbb88: $siteEntity = $this->siteEntityManager->createEntity(); goto C4335; a62ad: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto af7d1; Aea8e: $reverseProxySite->setRegistrableDomain($registrableDomain); goto A43eb; e160f: $vhostTemplate = sprintf("\x25\x73\x25\x73", $redirectionVhostTemplate, $vhostTemplate); goto d9262; f6d87: if (!(false === empty($redirectionVhostTemplate))) { goto df490; } goto e160f; edada: Eb769: goto c9717; b87a0: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto Dbb88; b9297: $reverseProxySite->setUserPassword($siteEntity->getUserPassword()); goto b8158; A3c54: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto Ce3ce; ded38: $reverseProxySite->setRootDirectory($siteEntity->getRootDirectory()); goto eb0b0; e3023: if (!(false === is_null($subdomain) && "\x77\x77\167" == $subdomain)) { goto C4c45; } goto Cf873; Fdacd: $this->siteEntityManager->updateEntity($siteEntity); goto acb9f; bff36: $subdomain = false === empty($subdomain) ? $subdomain : null; goto fd4b2; b5340: $reverseProxySite->setReverseProxyUrl($reverseProxyUrl); goto d67a2; Fc4bb: $siteConstraints = $this->validator->validate($siteEntity); goto fc9ca; acb9f: return $siteEntity; goto c1109; Fd757: $siteEntity->setRootDirectory($domainName); goto af6f8; caff4: $certificateEntity = $this->certificateEntityManager->createEntity(); goto c759c; f77be: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto c2e14; ba2c6: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto B0140; C7cb9: $csr = $csrGenerator->generate(); goto a62ad; af6f8: $siteEntity->setReverseProxyUrl($reverseProxyUrl); goto b1c1c; fd4b2: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::REVERSE_PROXY_VHOST_TEMPLATE_NAME); goto b87a0; B9bc0: $reversProxySiteCreator->createLogrotateFile(); goto e3d95; Cf873: $subjectAlternativeNames[] = $registrableDomain; goto db933; E9d83: $vhostTemplate->build(); goto d8ecb; d8ecb: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto B94ce; D712d: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto a7d54; c556d: $rsaKeyGenerator = new RsaKeyGenerator(); goto ba2c6; B73d7: $reversProxySiteCreator->createUser(); goto Cd63a; ce5b4: goto bcb6c; goto D430a; Cd63a: $reversProxySiteCreator->createRootDirectory(); goto B9bc0; db933: C4c45: goto D712d; f1962: $siteEntity->setUser($siteUser); goto b89f1; C4335: $siteEntity->setType(SiteEntity::TYPE_REVERSE_PROXY); goto E06ba; e3d95: $reversProxySiteCreator->createPrivateKeyAndCertificate(); goto bf503; c2e14: $vhostTemplate->resetProcessors(); goto F639d; b4d39: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto F01c3; Be492: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto f6d87; bf503: $reversProxySiteCreator->createNginxVhost(); goto c9828; d2b91: bcb6c: goto Be492; A065e: $certificateEntity->setCsr($csr); goto A3c54; B94ce: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto Fdacd; b12f2: $subjectAlternativeNames[] = sprintf("\x77\167\x77\56\x25\163", $domainName); goto e9a44; b1c1c: if (!(true === is_null($subdomain) || "\167\x77\167" == $subdomain)) { goto Eb769; } goto dac9e; e11c6: $reversProxySiteCreator->resetPermissions(); goto Eff2f; E32e3: $subdomain = $resolvedDomainName->subDomain()->toString(); goto bff36; F01c3: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto E32e3; F640e: f0086: goto caff4; ac7c0: $constraintViolationList = new ConstraintViolationList(); goto D0846; E06ba: $siteEntity->setDomainName($domainName); goto f1962; c759c: $certificateEntity->setSite($siteEntity); goto c556d; a7d54: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto C7cb9; af7d1: $certificateEntity->setDefaultCertificate(true); goto F7c59; b89f1: $siteEntity->setUserPassword($siteUserPassword); goto Fd757; f1069: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto B84df; c9828: $reversProxySiteCreator->reloadNginxService(); goto e11c6; D0846: $constraintViolationList->addAll($siteConstraints); goto bb76e; b8158: $reverseProxySite->setDomainName($domainName); goto Aea8e; F7c59: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto A065e; A43eb: $reverseProxySite->setSubdomain($subdomain); goto ded38; B0140: $subjectAlternativeNames = []; goto dff38; d67a2: $reverseProxySite->setVhostTemplate($siteEntity->getVhostTemplate()); goto D8767; F84b2: $siteEntity->setCertificate($certificateEntity); goto c330f; f6432: throw new \Exception(implode("\x3b\40", $errorMessages)); goto F640e; dac9e: if (true === isset($_ENV["\x41\120\x50\137\110\x54\124\120\63"]) && "\x74\162\165\x65" === $_ENV["\x41\x50\x50\137\110\x54\124\120\x33"]) { goto feeeb; } goto A9bb6; B84df: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto E9d83; eb0b0: $reverseProxySite->setCertificate($certificateEntity); goto b5340; c63bb: $reverseProxySite->setUser($siteEntity->getUser()); goto b9297; A51c5: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\x2e\56\x2f\x2e\56\57\56\56\57\162\145\x73\157\165\x72\143\145\163\x2f\156\147\x69\x6e\x78\57\x76\150\157\163\164\x5f\x74\145\155\160\x6c\x61\164\145\x2f\x72\x65\144\x69\162\x65\143\164\x2d\x68\164\164\160\63"); goto d2b91; Eff2f: $vhostTemplate = new ReverseProxyVhostTemplate($reverseProxySite); goto f77be; bb76e: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto f6432; e9a44: B51ee: goto e3023; A9bb6: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\56\x2f\x2e\x2e\x2f\56\x2e\x2f\162\145\x73\157\165\x72\x63\x65\163\57\x6e\x67\x69\156\x78\x2f\166\x68\x6f\x73\164\x5f\x74\145\x6d\x70\x6c\x61\164\145\x2f\x72\x65\x64\x69\162\145\143\x74"); goto ce5b4; D430a: feeeb: goto A51c5; d9262: df490: goto edada; c9717: $siteEntity->setVhostTemplate($vhostTemplate); goto Fc4bb; c1109: } public function installedWordPressSite(Request $request) : Response { goto Af25a; ebdeb: return $response; goto Ba631; d0452: $siteCredentials = $session->get("\x73\x69\164\x65\x43\x72\x65\144\x65\156\164\x69\x61\x6c\x73"); goto d9ba5; f08dd: c0023: goto Fe30b; d7a46: $response = $this->redirect($this->generateUrl("\x63\154\x70\137\x73\151\x74\145\163")); goto E9e2b; Af25a: $session = $request->getSession(); goto d0452; d9ba5: if (false === empty($siteCredentials)) { goto c0023; } goto d7a46; ae569: $response = $this->render("\106\x72\157\156\164\x65\x6e\144\57\123\151\164\145\57\x4e\145\x77\x2f\167\x6f\162\144\x70\x72\145\163\163\55\151\x6e\x73\164\x61\x6c\154\x65\144\x2e\x68\x74\155\x6c\x2e\164\167\151\x67", ["\x73\151\164\x65\x43\162\x65\x64\x65\x6e\164\x69\141\x6c\163" => $siteCredentials]); goto F4739; E9e2b: goto Badb3; goto f08dd; A0a56: Badb3: goto ebdeb; F4739: return $response; goto A0a56; Fe30b: $siteCredentials = $this->renderSiteCredentials($siteCredentials); goto ae569; Ba631: } private function renderSiteCredentials(array $siteCredentials) : string { goto Aba9c; d861f: return $renderedCredentials; goto c5fcd; Aba9c: $renderedCredentials = ''; goto cc25d; a3e3e: fdc73: goto d861f; cc25d: foreach ($siteCredentials as $section => $sectionData) { goto cc1d2; A354f: A0f7e: goto db5d9; F8ba9: E3127: goto E2331; E2331: $renderedCredentials .= PHP_EOL; goto A354f; cc1d2: $renderedCredentials .= $section . PHP_EOL; goto a81a4; a81a4: $renderedCredentials .= "\55\x2d\55\x2d\x2d\x2d\x2d\55\x2d\55\55\x2d\55\55\x2d\55\x2d\55\x2d\55\x2d\x2d\55\x2d\55\55\55\55\55\x2d\55\55\x2d\55\x2d\55\x2d\x2d\55\x2d\x2d\55\55\55\55\55\55\x2d\x2d\55\x2d\55\55\x2d" . PHP_EOL; goto Cc689; Cc689: foreach ($sectionData as $key => $value) { $renderedCredentials .= sprintf("\x25\x73\72\40\x25\x73", $key, $value) . PHP_EOL; Cd518: } goto F8ba9; db5d9: } goto a3e3e; c5fcd: } private function getVhostTemplateEntity(string $name) : mixed { goto E1055; E9e08: B6123: goto cc565; cc565: return $vhostTemplateEntity; goto ca7fa; e3fd7: if (!(true === is_null($vhostTemplateEntity))) { goto B6123; } goto E3613; E1055: $vhostTemplateEntity = $this->vhostTemplateEntityManager->findOneByName($name); goto e3fd7; E3613: throw new \Exception($this->translator->trans("\126\150\x6f\163\164\40\x54\145\x6d\x70\x6c\141\x74\145\40\x25\166\x68\157\163\x74\x54\x65\x6d\160\154\141\x74\x65\45\x20\144\157\145\x73\40\x6e\x6f\164\x20\x65\170\x69\163\164\x2e", ["\x25\x76\150\157\x73\x74\x54\145\x6d\160\x6c\x61\x74\x65\x25" => $name])); goto E9e08; ca7fa: } private function getConstraintViolationListErrorMessages(ConstraintViolationList $constraintViolationList) : array { goto d1bac; E80d0: f3f4e: goto ea376; c246d: foreach ($constraintViolationList as $constraint) { $errorMessages[] = sprintf("\x25\x73\x3a\x20\45\163", $constraint->getPropertyPath(), $constraint->getMessage()); a7dd2: } goto E80d0; ea376: return $errorMessages; goto fa090; d1bac: $errorMessages = []; goto c246d; fa090: } private function generateNameFromDomainName(string $domainName) : string { goto Dd4c4; c147f: if (!(false === empty($subdomain))) { goto Fcc90; } goto a932b; b0a03: Fcc90: goto eeaf4; Cca04: $name = $explodedRegistrableDomain[0] ?? ''; goto c147f; E51db: $subdomain = $resolvedDomainName->subDomain()->toString(); goto b73b3; Dd4c4: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto a6e09; eeaf4: goto e0dd3; goto e65ef; cc0ca: $name = $explodedRegistrableDomain[0] ?? ''; goto F0fd9; e65ef: a2370: goto cc0ca; Ea09d: $name = sprintf("\45\163\55\x25\x73", $explodedRegistrableDomain[0] ?? '', implode("\x2d", $explodedSubdomain)); goto b0a03; b73b3: $explodedRegistrableDomain = explode("\56", $registrableDomain); goto b0152; da01f: return $name; goto fb9c1; F0fd9: e0dd3: goto da01f; b0152: if ("\167\x77\167" == $subdomain) { goto a2370; } goto Cca04; a6e09: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto E51db; a932b: $explodedSubdomain = explode("\x2e", $subdomain); goto Ea09d; fb9c1: } private function getUniqueDatabaseName(string $databaseName) : string { goto b7c35; C19d6: Df69c: goto Fa48b; f0568: $databaseConnection = new DatabaseConnection($activeDatabaseServerEntity); goto d93a7; Cdbe0: if (!(0 < $i)) { goto B04fa; } goto d9c0e; fbe45: $uniqueDatabaseName = sprintf("\x25\163\55\x64\142", $uniqueDatabaseName); goto C19d6; Ace21: Fe7ad: goto f73ad; f73ad: return $uniqueDatabaseName; goto Afa70; Fa48b: $i = 0; goto f2959; E0b5b: if (!(strlen($uniqueDatabaseName) <= 3)) { goto Df69c; } goto fbe45; a5ab3: B04fa: goto c4048; c4048: $databaseExists = in_array($uniqueDatabaseName, $databases); goto a4b98; B38df: Ad1d8: goto Cdbe0; d93a7: $databases = $databaseConnection->getDatabases(); goto B38df; b7c35: $uniqueDatabaseName = $databaseName; goto E0b5b; a4b98: $i++; goto dd6d4; d9c0e: $uniqueDatabaseName = sprintf("\45\163\x2d\45\163", $databaseName, $i); goto a5ab3; dd6d4: if (true === $databaseExists) { goto Ad1d8; } goto Ace21; f2959: $activeDatabaseServerEntity = $this->databaseServerEntityManager->getActiveDatabaseServer(); goto f0568; Afa70: } private function getUniqueDatabaseUserName(string $databaseUserName) : string { goto Eff1d; bca27: if (!(strlen($uniqueDatabaseUserName) <= 3)) { goto dbabc; } goto A22b6; Cea0f: if (false === is_null($databaseUserEntity)) { goto b1314; } goto ab89c; E066d: $i = 0; goto E2fe9; cc07c: $uniqueDatabaseUserName = sprintf("\45\x73\55\45\163", $databaseUserName, $i); goto F154d; E2fe9: b1314: goto beb3d; beb3d: if (!(0 < $i)) { goto Afa73; } goto cc07c; f5ce4: dbabc: goto E066d; ffd2c: $i++; goto Cea0f; Eff1d: $uniqueDatabaseUserName = $databaseUserName; goto bca27; Bbadd: $databaseUserEntity = $this->databaseUserEntityManager->findOneByUserName($uniqueDatabaseUserName); goto ffd2c; D53d2: return $uniqueDatabaseUserName; goto Ec6c2; Aa6cc: $uniqueDatabaseUserName = mb_substr($uniqueDatabaseUserName, 0, 32); goto D53d2; F154d: Afa73: goto Bbadd; A22b6: $uniqueDatabaseUserName = sprintf("\45\163\x2d\x64\142", $uniqueDatabaseUserName); goto f5ce4; ab89c: da916: goto Aa6cc; Ec6c2: } private function hasPermissions() : bool { goto cd546; A02c8: return true; goto a0874; cd546: $user = $this->getUser(); goto D9291; a0874: C5a5a: goto A56cc; A56cc: return false; goto ff714; D9291: if (!(UserEntity::ROLE_USER != $user->getRole())) { goto C5a5a; } goto A02c8; ff714: } }
